==============
ESMLab-regrid
==============
.. image:: https://img.shields.io/circleci/project/github/NCAR/esmlab-regrid/master.svg?style=for-the-badge&logo=circleci
    :target: https://circleci.com/gh/NCAR/esmlab-regrid/tree/master

.. image:: https://img.shields.io/codecov/c/github/NCAR/esmlab-regrid.svg?style=for-the-badge
    :target: https://codecov.io/gh/NCAR/esmlab-regrid


.. image:: https://img.shields.io/readthedocs/esmlab-regrid/latest.svg?style=for-the-badge
    :target: https://esmlab-regrid.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/esmlab-regrid.svg?style=for-the-badge
    :target: https://pypi.org/project/esmlab-regrid
    :alt: Python Package Index

.. image:: https://img.shields.io/conda/vn/conda-forge/esmlab-regrid.svg?style=for-the-badge
    :target: https://anaconda.org/conda-forge/esmlab-regrid
    :alt: Conda Version


ESMLab regridding utitilies. See documentation_ for more information.

.. _documentation: https://esmlab-regrid.readthedocs.io/en/latest/


Installation
------------

ESMLab-regrid can be installed from PyPI with pip:

.. code-block:: bash

    pip install esmlab-regrid


It is also available from `conda-forge` for conda installations:

.. code-block:: bash

    conda install -c conda-forge esmlab-regrid
